@@ -80,6 +80,7 @@ class JenkinsDatabaserArgumentsMixin(JenkinsArgumentsMixin):
         --jenkins_username
         --jenkins_password
         --jenkins_stands_view_name
+        --jenkins_databaser_folder_name
         --jenkins_databaser_job_name
         --jenkins_databaser_excluded_tables
         --jenkins_databaser_new_jira_filter
@@ -94,6 +95,11 @@ class JenkinsDatabaserArgumentsMixin(JenkinsArgumentsMixin):
 
         self._arguments_schema.extend(
             (
+                {
+                    'section': 'jenkins',
+                    'option': 'databaser_folder_name',
+                    'help': 'Имя папки Job-а для запуска сборки среза БД при помощи Databaser в Jenkins.',
+                },
                 {
                     'section': 'jenkins',
                     'option': 'databaser_job_name',
